==> regina-normal_5.1.orig.tar.gz: regina-5.1/python/helpers.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/*! \file python/helpers.h
 *  \brief Various tools to assist with Python bindings for Regina.
 */

#ifndef __HELPERS_H
#ifndef __DOXYGEN
#define __HELPERS_H
#endif

#include "helpers/equality.h"
#include "helpers/output.h"

#if BOOST_VERSION >= 106000 && BOOST_VERSION < 106100
    // Boost.Python 1.60 did not automatically register to_python converters
    // for SafeHeldType.
    #define FIX_REGINA_BOOST_CONVERTERS(T) \
        register_ptr_to_python<regina::python::SafeHeldType<T>>()
#else
    #define FIX_REGINA_BOOST_CONVERTERS(T)
#endif

#endif

==> regina-normal_6.0.1.orig.tar.gz: regina-6.0.1/python/helpers.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2021, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/*! \file python/helpers.h
 *  \brief Various tools to assist with Python bindings for Regina.
 */

#ifndef __HELPERS_H
#ifndef __DOXYGEN
#define __HELPERS_H
#endif

#include "pybind11/pybind11.h"
#include "helpers/equality.h"
#include "helpers/output.h"

// Inform pybind11 that SafePtr can be used as a holder type, and that it
// is safe to construct multiple holders from the same T*.

namespace regina {
    template <typename T> class SafePtr;
}
PYBIND11_DECLARE_HOLDER_TYPE(T, regina::SafePtr<T>, true);

#endif
